Module tree

Module tree 

Structs

BranchIterator
An iterator for a branch of the tree tree
ChildIterator
Iterator for iterating through the children of an entity.
ParentIterator
Iterator for iterating through the ancestors of an entity
Tree
The tree describes a tree of entities
TreeIterator
Iterator for iterating through the tree from top to bottom in depth first order

Enums

TreeError

Traits

IntoBranchIterator
IntoChildIterator
IntoParentIterator
IntoTreeIterator
TreeExt
Trait which provides methods for investigating entity relations within the tree.